@@ -1,7 +1,7 @@
-cSS = function(K, rx)
+cSS = function(K, rx, eps=1e-8)
 {
   b = rx$coefficients
-  iiv = G2SWEEP(t(K) %*% rx$g2 %*% K)
+  iiv = G2SWEEP(t(K) %*% rx$g2 %*% K, Augmented=FALSE, eps=eps)
   Q = t(t(K) %*% b) %*% iiv %*% t(K) %*% b
   Df = attr(iiv, "rank")
   MS = ifelse(Df > 0, Q/Df, NA)
